@@ -14,8 +14,6 @@ logger = logging.getLogger(__name__)
 
 
 def main(args):
-    configure_logger(LOG_DIR / 'watch.log')
-
     s3 = AWS_S3()
     w = WindowMgr()
 
@@ -37,4 +35,10 @@ if __name__ == '__main__':
     parser = ArgumentParser()
     parser.add_argument("window_name")
     parser.add_argument("--delay", type=int, default=60)
-    main(parser.parse_args())
+
+    configure_logger(LOG_DIR / 'watch.log')
+    try:
+        main(parser.parse_args())
+    except Exception as e:
+        logger.exception(e)
+        raise
